From b0b5c92469f03445e00407fb1109d249a4a8db43 Mon Sep 17 00:00:00 2001
From: foreman
Date: Thu, 12 Sep 2019 14:35:36 -0400
Subject: [PATCH] P4 to Git Change 1997621 by cpaquot@cpaquot-ocl-lc-lnx on
2019/09/12 14:16:09
SWDEV-145570 - Fixed some logging issues regarding hip(Ext)ModuleLaunchXXX.
Affected files ...
... //depot/stg/opencl/drivers/opencl/api/hip/hip_module.cpp#40 edit
---
hipamd/api/hip/hip_module.cpp | 28 +++++++++++++++++++++++-----
1 file changed, 23 insertions(+), 5 deletions(-)
diff --git a/hipamd/api/hip/hip_module.cpp b/hipamd/api/hip/hip_module.cpp
index c29fec995c..542cd89551 100644
--- a/hipamd/api/hip/hip_module.cpp
+++ b/hipamd/api/hip/hip_module.cpp
@@ -218,11 +218,6 @@ hipError_t ihipModuleLaunchKernel(hipFunction_t f,
hipEvent_t startEvent, hipEvent_t stopEvent, uint32_t flags = 0,
uint32_t params = 0)
{
- HIP_INIT_API(f, gridDimX, gridDimY, gridDimZ,
- blockDimX, blockDimY, blockDimZ,
- sharedMemBytes, hStream,
- kernelParams, extra, startEvent, stopEvent, flags);
-
hip::Function* function = hip::Function::asFunction(f);
amd::Kernel* kernel = function->function_;
amd::Device* device = hip::getCurrentContext()->devices()[0];
@@ -320,6 +315,11 @@ hipError_t hipModuleLaunchKernel(hipFunction_t f,
uint32_t sharedMemBytes, hipStream_t hStream,
void **kernelParams, void **extra)
{
+ HIP_INIT_API(f, gridDimX, gridDimY, gridDimZ,
+ blockDimX, blockDimY, blockDimZ,
+ sharedMemBytes, hStream,
+ kernelParams, extra);
+
HIP_RETURN(ihipModuleLaunchKernel(f, gridDimX * blockDimX, gridDimY * blockDimY, gridDimZ * blockDimZ,
blockDimX, blockDimY, blockDimZ,
sharedMemBytes, hStream, kernelParams, extra, nullptr, nullptr));
@@ -332,6 +332,11 @@ hipError_t hipExtModuleLaunchKernel(hipFunction_t f, uint32_t globalWorkSizeX,
hipStream_t hStream, void** kernelParams, void** extra,
hipEvent_t startEvent, hipEvent_t stopEvent, uint32_t flags)
{
+ HIP_INIT_API(f, globalWorkSizeX, globalWorkSizeY, globalWorkSizeZ,
+ localWorkSizeX, localWorkSizeY, localWorkSizeZ,
+ sharedMemBytes, hStream,
+ kernelParams, extra, startEvent, stopEvent, flags);
+
HIP_RETURN(ihipModuleLaunchKernel(f, globalWorkSizeX, globalWorkSizeY, globalWorkSizeZ, localWorkSizeX, localWorkSizeY,
localWorkSizeZ, sharedMemBytes, hStream, kernelParams, extra, startEvent, stopEvent, flags));
}
@@ -346,6 +351,11 @@ hipError_t hipHccModuleLaunchKernel(hipFunction_t f, uint32_t gridDimX,
hipEvent_t startEvent,
hipEvent_t stopEvent)
{
+ HIP_INIT_API(f, gridDimX, gridDimY, gridDimZ,
+ blockDimX, blockDimY, blockDimZ,
+ sharedMemBytes, hStream,
+ kernelParams, extra, startEvent, stopEvent);
+
HIP_RETURN(ihipModuleLaunchKernel(f, gridDimX, gridDimY, gridDimZ, blockDimX, blockDimY, blockDimZ,
sharedMemBytes, hStream, kernelParams, extra, startEvent, stopEvent));
}
@@ -358,6 +368,11 @@ hipError_t hipModuleLaunchKernelExt(hipFunction_t f, uint32_t gridDimX,
hipEvent_t startEvent,
hipEvent_t stopEvent)
{
+ HIP_INIT_API(f, gridDimX, gridDimY, gridDimZ,
+ blockDimX, blockDimY, blockDimZ,
+ sharedMemBytes, hStream,
+ kernelParams, extra, startEvent, stopEvent);
+
HIP_RETURN(ihipModuleLaunchKernel(f, gridDimX, gridDimY, gridDimZ, blockDimX, blockDimY, blockDimZ,
sharedMemBytes, hStream, kernelParams, extra, startEvent, stopEvent));
}
@@ -366,6 +381,9 @@ hipError_t hipLaunchCooperativeKernel(const void* f,
dim3 gridDim, dim3 blockDim,
void **kernelParams, uint32_t sharedMemBytes, hipStream_t hStream)
{
+ HIP_INIT_API(f, gridDim, blockDim,
+ sharedMemBytes, hStream);
+
int deviceId = ihipGetDevice();
hipFunction_t func = PlatformState::instance().getFunc(f, deviceId);
if (func == nullptr) {